@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2006 Henning Norén
+ * Copyright (C) 2006-2008 Henning Norén
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -50,16 +50,21 @@ wlSetPassword(uint8_t *outbuf) {
   passlength = 0;
 
   ch = getc(wordList);
-  while(ch != '\n' && ch != EOF && passlength < 32) {
+  while(ch != '\n' && ch != '\r' && ch != EOF && passlength < 32) {	
     outbuf[passlength++] = ch;
     ch = getc(wordList);
   }
 
   /** clean up garbage of passwords longed than 32 chars */
   if(unlikely(passlength == 32))
-    while(ch != '\n' && ch != EOF)
+    while(ch != '\n' && ch != '\r' && ch != EOF)
       ch = getc(wordList);
 
+  if(ch == '\r') {
+    ch = getc(wordList);
+    if(ch != '\n')
+      ungetc(ch, wordList);
+  }
   if(unlikely(ch == EOF))
     wlMore = false;
 
@@ -133,7 +138,7 @@ setCharset(const char *cs, const unsigned int minPw,
       charset = stdchars;
     charsetLen = strlen((const char*)charset);
 
-    /** Make sure that max- and min-password is smaller than 32 */
+    /** Make sure that max- and min-password are smaller than 32 */
     if(maxPw < PASSLENGTH)
       maxPasswordLen = maxPw;
     else
