@@ -194,24 +194,33 @@ static bool (*permutate)() = NULL;
 static void
 foundPassword(void) {
   char str[33];
+  int fin_search;
+  size_t pad_start;
 
   memcpy(str,currPW,currPWLen);
   str[currPWLen] = '\0';
   printf("found %s-password: '%s'\n", workWithUser?"user":"owner", str);
 
-  /** The only password that can be found in plaintext is the password pointed
-      to by currPW. If SHOWUSERPASSWORD is define we will get the password
-      via user_password _including_ the pad.
-      For this to be really usable we would print out the possible userpasswords
-      based on finding possible beginnings of the pad (there are real passwords
-      which can be used which matches the same as a padded (not that it really
-      matters)).
-  */
+  /** 
+   * Print out the user-password too if we know the ownerpassword.
+   * It is placed in password_user and we need to find where the pad
+   * starts before we can print it out (without ugly artifacts) 
+   **/
 
-#ifdef SHOWUSERPASSWORD
-  if(!workWithUser)
-    printf("found user-password: '%s'\n", password_user);
-#endif
+  if(!workWithUser) {
+    fin_search=-1;
+    pad_start=0;
+
+    do {
+      fin_search = memcmp(password_user+pad_start, pad, 32-pad_start);
+      pad_start++;
+    } while (pad_start < 32 && fin_search != 0);
+
+    memcpy(str, password_user, pad_start);
+    if(!fin_search)
+      str[pad_start-1] = '\0';
+    printf("found user-password: '%s'\n", str);
+  }
 }
 
 /** Common handling of the key for all rev3-functions */
@@ -288,9 +297,7 @@ runCrackRev2_o(void) {
       rc4Decrypt(enckey, encdata->o_string, 32, encKeyWorkSpace);
       md5(encKeyWorkSpace, ekwlen, enckey);
       if(rc4Match40b(enckey, encdata->u_string, pad)) {
-#ifdef SHOWUSERPASSWORD
 	memcpy(password_user, encKeyWorkSpace, 32);
-#endif
 	return true;
       }
 
@@ -322,9 +329,7 @@ runCrackRev3_o(void) {
       memcpy(encKeyWorkSpace, test, 32);
 
       if(isUserPasswordRev3()) {
-#ifdef SHOWUSERPASSWORD
         memcpy(password_user, encKeyWorkSpace, 32);
-#endif
 	return true;
       }
 
@@ -451,12 +456,13 @@ runCrackRev2(void) {
 }
 
 /** Start cracking and does not stop until it has either been interrupted by
-    a signal or the password either is found or not found.
+    a signal or the password either is found or wordlist or charset is exhausted
 */
 void
 runCrack(void) {
   bool found = false;
   uint8_t cpw[32];
+
   if(!workWithUser && !knownPassword) {
     memcpy(cpw, pad, 32);
     currPW = cpw;
