@@ -163,14 +163,13 @@ isWord(FILE *file, const char *str) {
 bool
 openPDF(FILE *file, EncData *e) {
   bool ret = false;
-  int ch, minor_v = 0, major_v = 0;
+  int minor_v = 0, major_v = 0;
   if(getc(file) == '%' && getc(file) == 'P' && getc(file) == 'D' 
      && getc(file) == 'F' && getc(file) == '-') {
     major_v = parseInt(file);
     if(getc(file) == '.')
       minor_v = parseInt(file);
-    ch = getc(file);
-    if(major_v >= 0 && isEndOfLine(ch))
+    if(major_v >= 0)
       ret = true;
   }
 
@@ -493,11 +492,12 @@ parseEncrypObject(FILE *file, EncData *e) {
 	break;
       case 'O':
 	str = parseRegularString(file);
+	if(!str)
+	  break;
 	if(str->len != 32)
 	  fprintf(stderr, "WARNING: O-String != 32 Bytes: %d\n", str->len);
 	e->o_string = str->content;
-     	if(str)
-	  free(str);
+	free(str);
 	fo = true;
 	break;
       case 'P':
@@ -518,11 +518,12 @@ parseEncrypObject(FILE *file, EncData *e) {
 	break;
       case 'U':
 	str = parseRegularString(file);
+	if(!str)
+	  break;
 	if(str->len != 32)
 	  fprintf(stderr, "WARNING: U-String != 32 Bytes: %d\n", str->len);
 	e->u_string = str->content;
-	if(str)
-	  free(str);
+	free(str);
 	fu = true;
 	break;
       case 'V':
@@ -591,7 +592,7 @@ getEncryptedInfo(FILE *file, EncData *e) {
   int e_pos = -1;
   bool ret;
 
-  if(!fseek(file, 0L, SEEK_END-1024))
+  if(fseek(file, 0L, SEEK_END-1024))
     e_pos = findTrailer(file, e);
   if(e_pos < 0) {
     rewind(file);
